@@ -96,6 +96,8 @@ def _walk(tokens: Iterator[str], terminator: str = None, limit: int = 0) -> List
                     children = tuple(_walk(tokens, terminator=terminator, limit=1))
                 except NoAvailableTokensError:
                     raise MissingSuperScriptOrSubscriptError
+                if previous.token in (commands.OVERBRACE, commands.UNDERBRACE):
+                    modifier = previous.token
                 node = Node(token=token, children=(previous, *children), modifier=modifier)
         elif token == commands.APOSTROPHE:
             try:
@@ -121,6 +123,16 @@ def _walk(tokens: Iterator[str], terminator: str = None, limit: int = 0) -> List
         elif token in commands.COMMANDS_WITH_ONE_PARAMETER or token.startswith(commands.MATH):
             children = tuple(_walk(tokens, terminator=terminator, limit=1))
             node = Node(token=token, children=children)
+        elif token in (commands.XLEFTARROW, commands.XRIGHTARROW):
+            children = tuple(_walk(tokens, terminator=terminator, limit=1))
+            if children[0].token == commands.OPENING_BRACKET:
+                children = (
+                    Node(
+                        token=commands.BRACES, children=tuple(_walk(tokens, terminator=commands.CLOSING_BRACKET))[:-1]
+                    ),
+                    *tuple(_walk(tokens, terminator=terminator, limit=1)),
+                )
+            node = Node(token=token, children=children)
         elif token in (commands.HSKIP, commands.HSPACE, commands.KERN, commands.MKERN, commands.MSKIP, commands.MSPACE):
             children = tuple(_walk(tokens, terminator=terminator, limit=1))
             if children[0].token == commands.BRACES and children[0].children is not None:
@@ -275,13 +287,19 @@ def _walk(tokens: Iterator[str], terminator: str = None, limit: int = 0) -> List
                         children=(
                             Node(
                                 token=commands.VPHANTOM,
-                                children=(Node(token=operator.token, attributes=attributes),),
+                                children=(
+                                    Node(token=operator.token, children=operator.children, attributes=attributes),
+                                ),
                             ),
                             *left_children,
                         ),
                     ),
                     Node(
-                        token=right_token, children=(Node(token=operator.token, attributes=attributes), *right_children)
+                        token=right_token,
+                        children=(
+                            Node(token=operator.token, children=operator.children, attributes=attributes),
+                            *right_children,
+                        ),
                     ),
                 ),
             )
@@ -312,25 +330,22 @@ def _walk(tokens: Iterator[str], terminator: str = None, limit: int = 0) -> List
 def _make_subsup(node: Node) -> Tuple[str, Tuple[Node, ...]]:
     # TODO: raise error instead of assertion
     assert node.token == commands.BRACES
-    assert (
-        node.children is not None
-        and 2 <= len(node.children[0].children) <= 3
-        and node.children[0].token
-        in (
-            commands.SUBSUP,
-            commands.SUBSCRIPT,
-            commands.SUPERSCRIPT,
+    try:
+        assert (
+            node.children is not None
+            and 2 <= len(node.children[0].children) <= 3
+            and node.children[0].token
+            in (
+                commands.SUBSUP,
+                commands.SUBSCRIPT,
+                commands.SUPERSCRIPT,
+            )
         )
-    )
-    token = node.children[0].token
-    children = node.children[0].children[1:]
-    if token == commands.SUBSCRIPT:
-        token = commands.SUBSUP
-        children = (*children, Node(token=""))
-    elif token == commands.SUPERSCRIPT:
-        token = commands.SUBSUP
-        children = (Node(token=""), *children)
-    return token, children
+        token = node.children[0].token
+        children = node.children[0].children[1:]
+        return token, children
+    except IndexError:
+        return "", ()
 
 
 def _get_dimension(node: Node) -> str:
